==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/InsertBlockItem/ts/InsertBlockItem_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>InsertBlockItem</name>
    <message>
        <source>Insert Block</source>
        <translation type="obsolete">Insérer bloc</translation>
    </message>
    <message>
        <location filename="../InsertBlockItem.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotation :</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Pivoter les entités&lt;br&gt;collées par cet angle</translation>
    </message>
    <message>
        <location line="+90"/>
        <source>Scale:</source>
        <translation>Echelle :</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Échelle des entités&lt;br&gt;collées par ce facteur</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Retourner les entités&lt;br&gt;collé horizontalement</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Retourner les entités&lt;br&gt;collées verticalement</translation>
    </message>
    <message>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation type="obsolete">Coller toutes les entités&lt;br&gt;de la calque actuelle&lt;br&gt;place de la calque d&apos;origine</translation>
    </message>
    <message>
        <source>To current layer</source>
        <translation type="obsolete">Vers le calque courant</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Ecraser les calques existantes&lt;br&gt;dans le dessin avec les&lt;br&gt;calques du presse-papiers</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Ecraser les calques</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Ecraser les blocs existants&lt;br&gt;dans le dessin avec des&lt;br&gt;blocs du presse-papiers</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Ecraser les blocs</translation>
    </message>
    <message>
        <location filename="../InsertBlockItem.js" line="+88"/>
        <source>Cannot import file from URL: </source>
        <translation>Ne peux pas importer le fichier depuis l&apos;URL : </translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Adjusted invalid block name to &apos;%1&apos;</source>
        <translation>Ajusté nom de bloc invalide &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+55"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../InsertBlockItemInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;Insérer bloc</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/InsertBlockItem/ts/InsertBlockItem_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>InsertBlockItem</name>
    <message>
        <source>Insert Block</source>
        <translation type="obsolete">Insérer bloc</translation>
    </message>
    <message>
        <location filename="../InsertBlockItem.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotation :</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Pivoter les entités&lt;br&gt;collées par cet angle</translation>
    </message>
    <message>
        <location line="+100"/>
        <source>Scale:</source>
        <translation>Echelle :</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Mise à l&apos;échelle des entités&lt;br&gt;collées par ce facteur</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Retourner les entités&lt;br&gt;collées horizontalement</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Retourner les entités&lt;br&gt;collées verticalement</translation>
    </message>
    <message>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation type="obsolete">Coller toutes les entités&lt;br&gt;de la calque actuelle&lt;br&gt;place de la calque d&apos;origine</translation>
    </message>
    <message>
        <source>To current layer</source>
        <translation type="obsolete">Vers le calque courant</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Ecraser les calques existants&lt;br&gt;dans le dessin avec les&lt;br&gt;calques du presse-papiers</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Ecraser les calques</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Ecraser les blocs existants&lt;br&gt;dans le dessin avec des&lt;br&gt;blocs du presse-papiers</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Ecraser les blocs</translation>
    </message>
    <message>
        <location filename="../InsertBlockItem.js" line="+102"/>
        <source>Cannot import file from URL: </source>
        <translation>Ne peux pas importer le fichier depuis l&apos;URL : </translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Adjusted invalid block name to &apos;%1&apos;</source>
        <translation>Corrigé nom de bloc invalide &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../InsertBlockItemInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;Insérer bloc</translation>
    </message>
</context>
</TS>
